# amsc

[![Release](https://img.shields.io/github/v/release/saforem2/amsc)](https://img.shields.io/github/v/release/saforem2/amsc)
[![Build status](https://img.shields.io/github/actions/workflow/status/saforem2/amsc/main.yml?branch=main)](https://github.com/saforem2/amsc/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/saforem2/amsc)](https://img.shields.io/github/commit-activity/m/saforem2/amsc)
[![License](https://img.shields.io/github/license/saforem2/amsc)](https://img.shields.io/github/license/saforem2/amsc)

American Science Cloud
